summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/religion.cc
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-11-24 21:43:51 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-11-24 21:43:51 +0000
commit1c5dd2f5fa1e94a5f6017f391e4b1d192b7d706c (patch)
treebe0c9c397bb4428abc4aa148c687db16d14d8b5b /crawl-ref/source/religion.cc
parent0e3ada71c222f6905af710f63177bbee83bd409b (diff)
downloadcrawl-ref-1c5dd2f5fa1e94a5f6017f391e4b1d192b7d706c.tar.gz
crawl-ref-1c5dd2f5fa1e94a5f6017f391e4b1d192b7d706c.zip
Clean up ability handling to display costs for prayer-activated
abilities (Zin's sustenance and Yred's injury mirror) in a less hackish way. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@7593 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/religion.cc')
-rw-r--r--crawl-ref/source/religion.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/crawl-ref/source/religion.cc b/crawl-ref/source/religion.cc
index c77c50abb9..49f9f8b5a3 100644
--- a/crawl-ref/source/religion.cc
+++ b/crawl-ref/source/religion.cc
@@ -3474,7 +3474,7 @@ bool ely_destroy_weapons()
GOD_ELYVILON);
}
- destroy_item( si.link() );
+ destroy_item(si.link());
success = true;
}
@@ -3484,8 +3484,8 @@ bool ely_destroy_weapons()
return (success);
}
-// Returns false if the invocation fails (no books in sight etc.).
-bool trog_burn_books()
+// Returns false if the invocation fails (no spellbooks in sight, etc.).
+bool trog_burn_spellbooks()
{
if (you.religion != GOD_TROG)
return (false);
@@ -3534,7 +3534,7 @@ bool trog_burn_books()
continue;
}
- rarity += book_rarity( si->sub_type );
+ rarity += book_rarity(si->sub_type);
// Piety increases by 2 for books never cracked open, else 1.
// Conversely, rarity influences the duration of the pyre.
if (!item_type_known(*si))
@@ -3554,8 +3554,8 @@ bool trog_burn_books()
if (cloud != EMPTY_CLOUD)
{
// Reinforce the cloud.
- mpr( "The fire roars with new energy!" );
- const int extra_dur = count + random2(rarity/2);
+ mpr("The fire roars with new energy!");
+ const int extra_dur = count + random2(rarity / 2);
env.cloud[cloud].decay += extra_dur * 5;
env.cloud[cloud].set_whose(KC_YOU);
continue;
@@ -3566,7 +3566,7 @@ bool trog_burn_books()
if (durat > 23)
durat = 23;
- place_cloud( CLOUD_FIRE, *ri, durat, KC_YOU );
+ place_cloud(CLOUD_FIRE, *ri, durat, KC_YOU);
mpr(count == 1 ? "The book bursts into flames."
: "The books burst into flames.", MSGCH_GOD);